@@ -408,7 +408,8 @@ class Client(object):
         subscription_list.subscription.extend(subscriptions)
         return self.subscribe([subscription_list])
 
-    def parse_xpath_to_gnmi_path(self, xpath, origin=None):
+    @classmethod
+    def parse_xpath_to_gnmi_path(cls, xpath, origin=None):
         """Parses an XPath to proto.gnmi_pb2.Path.
         This function should be overridden by any child classes for origin logic.
 
